
# still-rm

A utility for removing still frames from video files using ffmpeg & opencv.

## Requirements
 - ffmpeg

## Installation

```
pip3 install still-rm
```

## Usage

```sh
still-rm /path/to/input.file /path/to/output.file

# options
still-rm -h
```
